SemanticSyntaxChecker for AST-based syntax errors.
This checker is not responsible for traversing the AST itself. Instead, its
SemanticSyntaxChecker::visit_stmt and SemanticSyntaxChecker::visit_expr methods should
be called in a parent Visitor’s visit_stmt and visit_expr methods, respectively.
Structs
Enums
- Await
Outside Async Function Kind - Invalid
Expression Kind - Invalid
Expression Position - Lazy
Import Context - Lazy
Import Kind - Semantic
Syntax Error Kind - Write
ToDebug Kind - Yield
Outside Function Kind
Traits
- Semantic
Syntax Context - Information needed from a parent visitor to emit semantic syntax errors.