pub struct SemanticSyntaxError {
pub kind: SemanticSyntaxErrorKind,
pub range: TextRange,
pub python_version: PythonVersion,
}Fields
kind: SemanticSyntaxErrorKindrange: TextRangepython_version: PythonVersionTrait Implementations
Sourceimpl Clone for SemanticSyntaxError
impl Clone for SemanticSyntaxError
Sourcefn clone(&self) -> SemanticSyntaxError
fn clone(&self) -> SemanticSyntaxError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticSyntaxError
impl Debug for SemanticSyntaxError
Sourceimpl Display for SemanticSyntaxError
impl Display for SemanticSyntaxError
Sourceimpl GetSize for SemanticSyntaxError
impl GetSize for SemanticSyntaxError
Sourcefn get_heap_size(&self) -> usize
fn get_heap_size(&self) -> usize
Determines how many bytes this object occupies inside the heap. Read more
Sourcefn get_heap_size_with_tracker<TRACKER: GetSizeTracker>(
&self,
tracker: TRACKER,
) -> (usize, TRACKER)
fn get_heap_size_with_tracker<TRACKER: GetSizeTracker>( &self, tracker: TRACKER, ) -> (usize, TRACKER)
Determines how many bytes this object occupies inside the heap while using a
tracker. Read moreSourcefn get_stack_size() -> usize
fn get_stack_size() -> usize
Determines how may bytes this object occupies inside the stack. Read more
Sourcefn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
fn get_size_with_tracker<T>(&self, tracker: T) -> (usize, T)where
T: GetSizeTracker,
Determines the total size of the object while using a
tracker. Read moreSourceimpl Hash for SemanticSyntaxError
impl Hash for SemanticSyntaxError
Sourceimpl PartialEq for SemanticSyntaxError
impl PartialEq for SemanticSyntaxError
Sourceimpl Ranged for SemanticSyntaxError
impl Ranged for SemanticSyntaxError
impl Eq for SemanticSyntaxError
impl StructuralPartialEq for SemanticSyntaxError