This module takes care of parsing a type annotation.
Structs
Enums
Functions
- parse_
type_ annotation - Parses the given string expression node as a type annotation. The given
sourceis the entire source code.
This module takes care of parsing a type annotation.
source is the entire
source code.